@@ -1,5 +1,5 @@
 /* tiger.c  -  The TIGER hash function
- * Copyright (C) 1998, 2001, 2002, 2003, 2010 Free Software Foundation, Inc.
+ *	Copyright (C) 1998, 2001, 2002, 2003 Free Software Foundation, Inc.
  *
  * This file is part of Libgcrypt.
  *
@@ -18,27 +18,25 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-/* See http://www.cs.technion.ac.il/~biham/Reports/Tiger/  */
-
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-
+#include <assert.h>
 #include "g10lib.h"
+#include "memory.h"
 #include "cipher.h"
-#include "hash-common.h"
-#include "bithelp.h"
-#include "bufhelp.h"
 
-/* We really need a 64 bit type for this code.  */
 #ifdef HAVE_U64_TYPEDEF
 
-typedef struct
-{
-  gcry_md_block_ctx_t bctx;
-  u64  a, b, c;
-  int  variant;  /* 0 = old code, 1 = fixed code, 2 - TIGER2.  */
+/* we really need it here, but as this is only experiment we
+ * can live without Tiger */
+
+typedef struct {
+    u64  a, b, c;
+    byte buf[64];
+    int  count;
+    u32  nblocks;
 } TIGER_CONTEXT;
 
 
@@ -589,270 +587,256 @@ static u64 sbox4[256] = {
   U64_C(0xc83223f1720aef96) /* 1022 */, U64_C(0xc3a0396f7363a51f) /* 1023 */
 };
 
-static unsigned int
-transform ( void *ctx, const unsigned char *data );
-
 static void
-do_init (void *context, int variant)
+tiger_init( void *context )
 {
-  TIGER_CONTEXT *hd = context;
-
-  hd->a = 0x0123456789abcdefLL;
-  hd->b = 0xfedcba9876543210LL;
-  hd->c = 0xf096a5b4c3b2e187LL;
-
-  hd->bctx.nblocks = 0;
-  hd->bctx.nblocks_high = 0;
-  hd->bctx.count = 0;
-  hd->bctx.blocksize = 64;
-  hd->bctx.bwrite = transform;
-  hd->variant = variant;
+  TIGER_CONTEXT *hd = (TIGER_CONTEXT *) context;
+    hd->a = 0x0123456789abcdefLL;
+    hd->b = 0xfedcba9876543210LL;
+    hd->c = 0xf096a5b4c3b2e187LL;
+    hd->nblocks = 0;
+    hd->count = 0;
 }
 
 static void
-tiger_init (void *context)
+round( u64 *ra, u64 *rb, u64 *rc, u64 x, int mul )
 {
-  do_init (context, 0);
-}
+    u64 a = *ra;
+    u64 b = *rb;
+    u64 c = *rc;
 
-static void
-tiger1_init (void *context)
-{
-  do_init (context, 1);
-}
+    c ^= x;
+    a -=   sbox1[  c	    & 0xff ] ^ sbox2[ (c >> 16) & 0xff ]
+	 ^ sbox3[ (c >> 32) & 0xff ] ^ sbox4[ (c >> 48) & 0xff ];
+    b +=   sbox4[ (c >>  8) & 0xff ] ^ sbox3[ (c >> 24) & 0xff ]
+	 ^ sbox2[ (c >> 40) & 0xff ] ^ sbox1[ (c >> 56) & 0xff ];
+    b *= mul;
 
-static void
-tiger2_init (void *context)
-{
-  do_init (context, 2);
-}
-
-static void
-tiger_round( u64 *ra, u64 *rb, u64 *rc, u64 x, int mul )
-{
-  u64 a = *ra;
-  u64 b = *rb;
-  u64 c = *rc;
-
-  c ^= x;
-  a -= (  sbox1[  c        & 0xff ] ^ sbox2[ (c >> 16) & 0xff ]
-        ^ sbox3[ (c >> 32) & 0xff ] ^ sbox4[ (c >> 48) & 0xff ]);
-  b += (  sbox4[ (c >>  8) & 0xff ] ^ sbox3[ (c >> 24) & 0xff ]
-        ^ sbox2[ (c >> 40) & 0xff ] ^ sbox1[ (c >> 56) & 0xff ]);
-  b *= mul;
-
-  *ra = a;
-  *rb = b;
-  *rc = c;
+    *ra = a;
+    *rb = b;
+    *rc = c;
 }
 
 
 static void
 pass( u64 *ra, u64 *rb, u64 *rc, u64 *x, int mul )
 {
-  u64 a = *ra;
-  u64 b = *rb;
-  u64 c = *rc;
+    u64 a = *ra;
+    u64 b = *rb;
+    u64 c = *rc;
 
-  tiger_round( &a, &b, &c, x[0], mul );
-  tiger_round( &b, &c, &a, x[1], mul );
-  tiger_round( &c, &a, &b, x[2], mul );
-  tiger_round( &a, &b, &c, x[3], mul );
-  tiger_round( &b, &c, &a, x[4], mul );
-  tiger_round( &c, &a, &b, x[5], mul );
-  tiger_round( &a, &b, &c, x[6], mul );
-  tiger_round( &b, &c, &a, x[7], mul );
+    round( &a, &b, &c, x[0], mul );
+    round( &b, &c, &a, x[1], mul );
+    round( &c, &a, &b, x[2], mul );
+    round( &a, &b, &c, x[3], mul );
+    round( &b, &c, &a, x[4], mul );
+    round( &c, &a, &b, x[5], mul );
+    round( &a, &b, &c, x[6], mul );
+    round( &b, &c, &a, x[7], mul );
 
-  *ra = a;
-  *rb = b;
-  *rc = c;
+    *ra = a;
+    *rb = b;
+    *rc = c;
 }
 
 
 static void
 key_schedule( u64 *x )
 {
-  x[0] -= x[7] ^ 0xa5a5a5a5a5a5a5a5LL;
-  x[1] ^= x[0];
-  x[2] += x[1];
-  x[3] -= x[2] ^ ((~x[1]) << 19 );
-  x[4] ^= x[3];
-  x[5] += x[4];
-  x[6] -= x[5] ^ ((~x[4]) >> 23 );
-  x[7] ^= x[6];
-  x[0] += x[7];
-  x[1] -= x[0] ^ ((~x[7]) << 19 );
-  x[2] ^= x[1];
-  x[3] += x[2];
-  x[4] -= x[3] ^ ((~x[2]) >> 23 );
-  x[5] ^= x[4];
-  x[6] += x[5];
-  x[7] -= x[6] ^ 0x0123456789abcdefLL;
+    x[0] -= x[7] ^ 0xa5a5a5a5a5a5a5a5LL;
+    x[1] ^= x[0];
+    x[2] += x[1];
+    x[3] -= x[2] ^ ((~x[1]) << 19 );
+    x[4] ^= x[3];
+    x[5] += x[4];
+    x[6] -= x[5] ^ ((~x[4]) >> 23 );
+    x[7] ^= x[6];
+    x[0] += x[7];
+    x[1] -= x[0] ^ ((~x[7]) << 19 );
+    x[2] ^= x[1];
+    x[3] += x[2];
+    x[4] -= x[3] ^ ((~x[2]) >> 23 );
+    x[5] ^= x[4];
+    x[6] += x[5];
+    x[7] -= x[6] ^ 0x0123456789abcdefLL;
 }
 
 
 /****************
  * Transform the message DATA which consists of 512 bytes (8 words)
  */
-static unsigned int
-transform ( void *ctx, const unsigned char *data )
+static void
+transform( TIGER_CONTEXT *hd, byte *data )
 {
-  TIGER_CONTEXT *hd = ctx;
-  u64 a,b,c,aa,bb,cc;
-  u64 x[8];
-  int i;
+    u64 a,b,c,aa,bb,cc;
+    u64 x[8];
+#ifdef WORDS_BIGENDIAN
+#define MKWORD(d,n) \
+		(  ((u64)(d)[8*(n)+7]) << 56 | ((u64)(d)[8*(n)+6]) << 48  \
+		 | ((u64)(d)[8*(n)+5]) << 40 | ((u64)(d)[8*(n)+4]) << 32  \
+		 | ((u64)(d)[8*(n)+3]) << 24 | ((u64)(d)[8*(n)+2]) << 16  \
+		 | ((u64)(d)[8*(n)+1]) << 8  | ((u64)(d)[8*(n)	])	 )
+    x[0] = MKWORD(data, 0);
+    x[1] = MKWORD(data, 1);
+    x[2] = MKWORD(data, 2);
+    x[3] = MKWORD(data, 3);
+    x[4] = MKWORD(data, 4);
+    x[5] = MKWORD(data, 5);
+    x[6] = MKWORD(data, 6);
+    x[7] = MKWORD(data, 7);
+#undef MKWORD
+#else
+    memcpy( &x[0], data, 64 );
+#endif
 
-  for ( i = 0; i < 8; i++ )
-    x[i] = buf_get_le64(data + i * 8);
+    /* save */
+    a = aa = hd->a;
+    b = bb = hd->b;
+    c = cc = hd->c;
 
-  /* save */
-  a = aa = hd->a;
-  b = bb = hd->b;
-  c = cc = hd->c;
+    pass( &a, &b, &c, x, 5);
+    key_schedule( x );
+    pass( &c, &a, &b, x, 7);
+    key_schedule( x );
+    pass( &b, &c, &a, x, 9);
 
-  pass( &a, &b, &c, x, 5);
-  key_schedule( x );
-  pass( &c, &a, &b, x, 7);
-  key_schedule( x );
-  pass( &b, &c, &a, x, 9);
+    /* feedforward */
+    a ^= aa;
+    b -= bb;
+    c += cc;
+    /* store */
+    hd->a = a;
+    hd->b = b;
+    hd->c = c;
+}
 
-  /* feedforward */
-  a ^= aa;
-  b -= bb;
-  c += cc;
-  /* store */
-  hd->a = a;
-  hd->b = b;
-  hd->c = c;
 
-  return /*burn_stack*/ 21*8+11*sizeof(void*);
+
+/* Update the message digest with the contents
+ * of INBUF with length INLEN.
+ */
+static void
+tiger_write( void *context, byte *inbuf, size_t inlen)
+{
+  TIGER_CONTEXT *hd = (TIGER_CONTEXT *) context;
+    if( hd->count == 64 ) { /* flush the buffer */
+	transform( hd, hd->buf );
+        _gcry_burn_stack (21*8+11*sizeof(void*));
+	hd->count = 0;
+	hd->nblocks++;
+    }
+    if( !inbuf )
+	return;
+    if( hd->count ) {
+	for( ; inlen && hd->count < 64; inlen-- )
+	    hd->buf[hd->count++] = *inbuf++;
+	tiger_write( hd, NULL, 0 );
+	if( !inlen )
+	    return;
+    }
+
+    while( inlen >= 64 ) {
+	transform( hd, inbuf );
+	hd->count = 0;
+	hd->nblocks++;
+	inlen -= 64;
+	inbuf += 64;
+    }
+    _gcry_burn_stack (21*8+11*sizeof(void*));
+    for( ; inlen && hd->count < 64; inlen-- )
+	hd->buf[hd->count++] = *inbuf++;
 }
 
 
 
 /* The routine terminates the computation
  */
+
 static void
 tiger_final( void *context )
 {
-  TIGER_CONTEXT *hd = context;
-  u32 t, th, msb, lsb;
-  byte *p;
-  unsigned int burn;
-  byte pad = hd->variant == 2? 0x80 : 0x01;
+  TIGER_CONTEXT *hd = (TIGER_CONTEXT *) context;
+    u32 t, msb, lsb;
+    byte *p;
 
-  _gcry_md_block_write(hd, NULL, 0); /* flush */;
+    tiger_write(hd, NULL, 0); /* flush */;
 
-  t = hd->bctx.nblocks;
-  if (sizeof t == sizeof hd->bctx.nblocks)
-    th = hd->bctx.nblocks_high;
-  else
-    th = hd->bctx.nblocks >> 32;
+    t = hd->nblocks;
+    /* multiply by 64 to make a byte count */
+    lsb = t << 6;
+    msb = t >> 26;
+    /* add the count */
+    t = lsb;
+    if( (lsb += hd->count) < t )
+	msb++;
+    /* multiply by 8 to make a bit count */
+    t = lsb;
+    lsb <<= 3;
+    msb <<= 3;
+    msb |= t >> 29;
 
-  /* multiply by 64 to make a byte count */
-  lsb = t << 6;
-  msb = (th << 6) | (t >> 26);
-  /* add the count */
-  t = lsb;
-  if( (lsb += hd->bctx.count) < t )
-    msb++;
-  /* multiply by 8 to make a bit count */
-  t = lsb;
-  lsb <<= 3;
-  msb <<= 3;
-  msb |= t >> 29;
-
-  if( hd->bctx.count < 56 )  /* enough room */
-    {
-      hd->bctx.buf[hd->bctx.count++] = pad;
-      while( hd->bctx.count < 56 )
-        hd->bctx.buf[hd->bctx.count++] = 0;  /* pad */
+    if( hd->count < 56 ) { /* enough room */
+	hd->buf[hd->count++] = 0x01; /* pad */
+	while( hd->count < 56 )
+	    hd->buf[hd->count++] = 0;  /* pad */
     }
-  else  /* need one extra block */
-    {
-      hd->bctx.buf[hd->bctx.count++] = pad; /* pad character */
-      while( hd->bctx.count < 64 )
-        hd->bctx.buf[hd->bctx.count++] = 0;
-      _gcry_md_block_write(hd, NULL, 0);  /* flush */;
-      memset(hd->bctx.buf, 0, 56 ); /* fill next block with zeroes */
+    else { /* need one extra block */
+	hd->buf[hd->count++] = 0x01; /* pad character */
+	while( hd->count < 64 )
+	    hd->buf[hd->count++] = 0;
+	tiger_write(hd, NULL, 0);  /* flush */;
+	memset(hd->buf, 0, 56 ); /* fill next block with zeroes */
     }
-  /* append the 64 bit count */
-  buf_put_le32(hd->bctx.buf + 56, lsb);
-  buf_put_le32(hd->bctx.buf + 60, msb);
-  burn = transform( hd, hd->bctx.buf );
-  _gcry_burn_stack (burn);
+    /* append the 64 bit count */
+    hd->buf[56] = lsb	   ;
+    hd->buf[57] = lsb >>  8;
+    hd->buf[58] = lsb >> 16;
+    hd->buf[59] = lsb >> 24;
+    hd->buf[60] = msb	   ;
+    hd->buf[61] = msb >>  8;
+    hd->buf[62] = msb >> 16;
+    hd->buf[63] = msb >> 24;
+    transform( hd, hd->buf );
+    _gcry_burn_stack (21*8+11*sizeof(void*));
 
-  p = hd->bctx.buf;
-#define X(a) do { *(u64*)p = be_bswap64(hd->a); p += 8; } while(0)
-#define Y(a) do { *(u64*)p = le_bswap64(hd->a); p += 8; } while(0)
-  if (hd->variant == 0)
-    {
-      X(a);
-      X(b);
-      X(c);
-    }
-  else
-    {
-      Y(a);
-      Y(b);
-      Y(c);
-    }
+    p = hd->buf;
+#ifdef WORDS_BIGENDIAN
+#define X(a) do { *(u64*)p = hd->a ; p += 8; } while(0)
+#else /* little endian */
+#define X(a) do { *p++ = hd->a >> 56; *p++ = hd->a >> 48; \
+		      *p++ = hd->a >> 40; *p++ = hd->a >> 32; \
+		      *p++ = hd->a >> 24; *p++ = hd->a >> 16; \
+		      *p++ = hd->a >>  8; *p++ = hd->a; } while(0)
+#endif
+    X(a);
+    X(b);
+    X(c);
 #undef X
-#undef Y
 }
 
 static byte *
 tiger_read( void *context )
 {
-  TIGER_CONTEXT *hd = context;
-
-  return hd->bctx.buf;
+  TIGER_CONTEXT *hd = (TIGER_CONTEXT *) context;
+  return hd->buf;
 }
 
-
-
-/* This is the old TIGER variant based on the unfixed reference
-   implementation.  IT was used in GnupG up to 1.3.2.  We don't provide
-   an OID anymore because that would not be correct.  */
-gcry_md_spec_t _gcry_digest_spec_tiger =
-  {
-    GCRY_MD_TIGER, {0, 0},
-    "TIGER192", NULL, 0, NULL, 24,
-    tiger_init, _gcry_md_block_write, tiger_final, tiger_read,
-    sizeof (TIGER_CONTEXT)
-  };
-
-
-
-/* This is the fixed TIGER implementation.  */
-static byte asn1[19] = /* Object ID is 1.3.6.1.4.1.11591.12.2 */
+static byte asn[19] = /* Object ID is 1.3.6.1.4.1.11591.12.2 */
   { 0x30, 0x29, 0x30, 0x0d, 0x06, 0x09, 0x2b, 0x06,
     0x01, 0x04, 0x01, 0xda, 0x47, 0x0c, 0x02,
     0x05, 0x00, 0x04, 0x18 };
 
-static gcry_md_oid_spec_t oid_spec_tiger1[] =
+static gcry_md_oid_spec_t oid_spec_tiger[] =
   {
     /* GNU.digestAlgorithm TIGER */
     { "1.3.6.1.4.1.11591.12.2" },
     { NULL }
   };
 
-gcry_md_spec_t _gcry_digest_spec_tiger1 =
+gcry_md_spec_t _gcry_digest_spec_tiger =
   {
-    GCRY_MD_TIGER1, {0, 0},
-    "TIGER", asn1, DIM (asn1), oid_spec_tiger1, 24,
-    tiger1_init, _gcry_md_block_write, tiger_final, tiger_read,
-    sizeof (TIGER_CONTEXT)
-  };
-
-
-
-/* This is TIGER2 which usues a changed padding algorithm.  */
-gcry_md_spec_t _gcry_digest_spec_tiger2 =
-  {
-    GCRY_MD_TIGER2, {0, 0},
-    "TIGER2", NULL, 0, NULL, 24,
-    tiger2_init, _gcry_md_block_write, tiger_final, tiger_read,
+    "TIGER192", asn, DIM (asn), oid_spec_tiger, 24,
+    tiger_init, tiger_write, tiger_final, tiger_read,
     sizeof (TIGER_CONTEXT)
   };
 
