@@ -1,6 +1,6 @@
 /* mpi-internal.h  -  Internal to the Multi Precision Integers
- * Copyright (C) 1994, 1996, 1998, 2000, 2002,
- *               2003 Free Software Foundation, Inc.
+ *	Copyright (C) 1998 Free Software Foundation, Inc.
+ *	Copyright (C) 1994, 1996, 2000, 2002, 2003 Free Software Foundation, Inc.
  *
  * This file is part of Libgcrypt.
  *
@@ -15,8 +15,8 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, see <https://www.gnu.org/licenses/>.
- * SPDX-License-Identifier: LGPL-2.1-or-later
+ * License along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  *
  * Note: This code is heavily based on the GNU MP Library.
  *	 Actually it's the same code with only minor changes in the
@@ -50,7 +50,6 @@
 #endif /*BITS_PER_MPI_LIMB*/
 
 #include "mpi.h"
-#include "const-time.h"
 
 /* If KARATSUBA_THRESHOLD is not already defined, define it to a
  * value which is good on most machines.  */
@@ -69,6 +68,9 @@
 #endif
 
 
+typedef mpi_limb_t *mpi_ptr_t; /* pointer to a limb */
+typedef int mpi_size_t;        /* (must be a signed type) */
+
 #define ABS(x) (x >= 0 ? x : -x)
 #define MIN(l,o) ((l) < (o) ? (l) : (o))
 #define MAX(h,i) ((h) > (i) ? (h) : (i))
@@ -77,11 +79,6 @@
 	if( (a)->alloced < (b) )   \
 	    mpi_resize((a), (b));  \
     } while(0)
-#define RESIZE_AND_CLEAR_IF_NEEDED(a,b) \
-    do {			   \
-	if( (a)->nlimbs < (b) )   \
-	    mpi_resize((a), (b));  \
-    } while(0)
 
 /* Copy N limbs from S to D.  */
 #define MPN_COPY( d, s, n) \
@@ -95,7 +92,7 @@
     do {				\
 	mpi_size_t _i;			\
 	for( _i = 0; _i < (n); _i++ )	\
-	    (d)[_i] = (s)[_i];		\
+	    (d)[_i] = (d)[_i];		\
     } while (0)
 
 #define MPN_COPY_DECR( d, s, n ) \
@@ -137,7 +134,7 @@
 	    mul_n_basecase (prodp, up, vp, size);	\
 	else						\
 	    mul_n (prodp, up, vp, size, tspace);	\
-    } while (0)
+    } while (0);
 
 
 /* Divide the two-limb number in (NH,,NL) by D, with DI being the largest
@@ -148,8 +145,7 @@
  */
 #define UDIV_QRNND_PREINV(q, r, nh, nl, d, di) \
     do {							    \
-        mpi_limb_t _ql GCC_ATTR_UNUSED;                               \
-	mpi_limb_t _q, _r;                                          \
+	mpi_limb_t _q, _ql, _r; 				    \
 	mpi_limb_t _xh, _xl;					    \
 	umul_ppmm (_q, _ql, (nh), (di));			    \
 	_q += (nh);	/* DI is 2**BITS_PER_MPI_LIMB too small */  \
@@ -173,15 +169,20 @@
 
 
 /*-- mpiutil.c --*/
+#ifdef M_DEBUG
+#define mpi_alloc_limb_space(n,f)  _gcry_mpi_debug_alloc_limb_space((n),(f), M_DBGINFO( __LINE__ ) )
+#define mpi_free_limb_space(n)  _gcry_mpi_debug_free_limb_space((n),  M_DBGINFO( __LINE__ ) )
+  mpi_ptr_t _gcry_mpi_debug_alloc_limb_space( unsigned nlimbs, int sec, const char *info  );
+  void _gcry_mpi_debug_free_limb_space( mpi_ptr_t a, const char *info );
+#else
 #define mpi_alloc_limb_space(n,f)  _gcry_mpi_alloc_limb_space((n),(f))
-mpi_ptr_t _gcry_mpi_alloc_limb_space( unsigned nlimbs, int sec );
-void _gcry_mpi_free_limb_space( mpi_ptr_t a, unsigned int nlimbs );
+#define mpi_free_limb_space(n)     _gcry_mpi_free_limb_space((n))
+  mpi_ptr_t _gcry_mpi_alloc_limb_space( unsigned nlimbs, int sec );
+  void _gcry_mpi_free_limb_space( mpi_ptr_t a );
+#endif
 void _gcry_mpi_assign_limb_space( gcry_mpi_t a, mpi_ptr_t ap, unsigned nlimbs );
 
 /*-- mpi-bit.c --*/
-#define mpi_rshift_limbs(a,n)  _gcry_mpi_rshift_limbs ((a), (n))
-#define mpi_lshift_limbs(a,n)  _gcry_mpi_lshift_limbs ((a), (n))
-
 void _gcry_mpi_rshift_limbs( gcry_mpi_t a, unsigned int count );
 void _gcry_mpi_lshift_limbs( gcry_mpi_t a, unsigned int count );
 
@@ -210,10 +211,8 @@ int _gcry_mpih_cmp( mpi_ptr_t op1_ptr, mpi_ptr_t op2_ptr, mpi_size_t size );
 struct karatsuba_ctx {
     struct karatsuba_ctx *next;
     mpi_ptr_t tspace;
-    unsigned int tspace_nlimbs;
     mpi_size_t tspace_size;
     mpi_ptr_t tp;
-    unsigned int tp_nlimbs;
     mpi_size_t tp_size;
 };
 
@@ -227,8 +226,6 @@ void _gcry_mpih_mul_n( mpi_ptr_t prodp, mpi_ptr_t up, mpi_ptr_t vp,
 						   mpi_size_t size);
 mpi_limb_t _gcry_mpih_mul( mpi_ptr_t prodp, mpi_ptr_t up, mpi_size_t usize,
 					 mpi_ptr_t vp, mpi_size_t vsize);
-mpi_limb_t _gcry_mpih_mul_lli(mpi_ptr_t prodp, mpi_ptr_t up, mpi_size_t usize,
-                              mpi_ptr_t vp, mpi_size_t vsize);
 void _gcry_mpih_sqr_n_basecase( mpi_ptr_t prodp, mpi_ptr_t up, mpi_size_t size );
 void _gcry_mpih_sqr_n( mpi_ptr_t prodp, mpi_ptr_t up, mpi_size_t size,
 						mpi_ptr_t tspace);
@@ -258,54 +255,6 @@ mpi_limb_t _gcry_mpih_lshift( mpi_ptr_t wp, mpi_ptr_t up, mpi_size_t usize,
 							   unsigned cnt);
 mpi_limb_t _gcry_mpih_rshift( mpi_ptr_t wp, mpi_ptr_t up, mpi_size_t usize,
 							   unsigned cnt);
-/*-- mpih-pow.c --*/
-void _gcry_mpih_powm_lli (mpi_ptr_t rp, mpi_ptr_t bp, mpi_ptr_t mp,
-                          mpi_size_t n, mpi_ptr_t ep, mpi_size_t en);
-
-/*-- mpih-const-time.c --*/
-#define mpih_set_cond(w,u,s,o) _gcry_mpih_set_cond ((w),(u),(s),(o))
-#define mpih_add_n_cond(w,u,v,s,o) _gcry_mpih_add_n_cond ((w),(u),(v),(s),(o))
-#define mpih_sub_n_cond(w,u,v,s,o) _gcry_mpih_sub_n_cond ((w),(u),(v),(s),(o))
-#define mpih_swap_cond(u,v,s,o) _gcry_mpih_swap_cond ((u),(v),(s),(o))
-#define mpih_abs_cond(w,u,s,o) _gcry_mpih_abs_cond ((w),(u),(s),(o))
-#define mpih_mod_lli(v,vs,u,us) _gcry_mpih_mod_lli ((v),(vs),(u),(us))
-
-DEFINE_CT_TYPE_GEN_MASK(limb, mpi_limb_t)
-DEFINE_CT_TYPE_GEN_INV_MASK(limb, mpi_limb_t)
-DEFINE_CT_TYPE_SELECT_FUNC(limb, mpi_limb_t)
-
-static inline int
-mpih_limb_is_zero (mpi_limb_t a)
-{
-  /* Sign bit set if A == 0. */
-  a = ~a & ~(-a);
-
-  return a >> (BITS_PER_MPI_LIMB - 1);
-}
-
-static inline int
-mpih_limb_is_not_zero (mpi_limb_t a)
-{
-  /* Sign bit set if A != 0. */
-  a = a | (-a);
-
-  return a >> (BITS_PER_MPI_LIMB - 1);
-}
-
-void _gcry_mpih_set_cond (mpi_ptr_t wp, mpi_ptr_t up, mpi_size_t usize,
-                          unsigned long op_enable);
-mpi_limb_t _gcry_mpih_add_n_cond (mpi_ptr_t wp, mpi_ptr_t up, mpi_ptr_t vp,
-                                  mpi_size_t usize, unsigned long op_enable);
-mpi_limb_t _gcry_mpih_sub_n_cond (mpi_ptr_t wp, mpi_ptr_t up, mpi_ptr_t vp,
-                                  mpi_size_t usize, unsigned long op_enable);
-void _gcry_mpih_swap_cond (mpi_ptr_t up, mpi_ptr_t vp, mpi_size_t usize,
-                           unsigned long op_enable);
-void _gcry_mpih_abs_cond (mpi_ptr_t wp, mpi_ptr_t up,
-                          mpi_size_t usize, unsigned long op_enable);
-void _gcry_mpih_lookup_lli (mpi_ptr_t rp, const mpi_limb_t *table,
-                            mpi_size_t n, mpi_size_t nents, mpi_size_t idx);
-mpi_ptr_t _gcry_mpih_mod_lli (mpi_ptr_t vp, mpi_size_t vsize,
-                              mpi_ptr_t up, mpi_size_t usize);
 
 
 /* Define stuff for longlong.h.  */
@@ -329,3 +278,4 @@ mpi_ptr_t _gcry_mpih_mod_lli (mpi_ptr_t vp, mpi_size_t vsize,
 #endif
 
 #endif /*G10_MPI_INTERNAL_H*/
+
